@@ -20,6 +20,7 @@ from datasetinsights.datasets import Dataset
 from datasetinsights.evaluation_metrics.base import EvaluationMetric
 from datasetinsights.io.bbox import BBox2D
 from datasetinsights.io.summarywriter import get_summary_writer
+from datasetinsights.io.tracker.factory import TrackerFactory
 from datasetinsights.io.transforms import Compose
 from datasetinsights.torch_distributed import get_world_size, is_master
 
@@ -31,6 +32,9 @@ DEFAULT_ACCUMULATION_STEPS = 1
 TRAIN = "train"
 VAL = "val"
 TEST = "test"
+_TRAIN_INTERMEDIATE_LOSS = "training/intermediate_loss"
+_TRAIN_LOSS = "training/loss"
+_VAL_LOSS = "val/loss"
 
 
 class FasterRCNN(Estimator):
@@ -110,6 +114,9 @@ class FasterRCNN(Estimator):
 
         if checkpoint_file:
             self.checkpointer.load(self, checkpoint_file)
+        self.mlflow_tracker = TrackerFactory.create(
+            config=config, tracker_type=TrackerFactory.MLFLOW_TRACKER
+        )
 
     def _init_distributed_mode(self):
         if "RANK" in os.environ and "WORLD_SIZE" in os.environ:
@@ -192,14 +199,27 @@ class FasterRCNN(Estimator):
         val_loader = dataloader_creator(
             config, val_dataset, val_sampler, VAL, self.distributed
         )
-        self.train_loop(
-            train_dataloader=train_loader,
-            label_mappings=label_mappings,
-            val_dataloader=val_loader,
-            train_sampler=train_sampler,
-        )
-        self.writer.close()
-        self.kfp_writer.write_metric()
+
+        params = self.config.clone()
+        if params.get(TrackerFactory.TRACKER):
+            params.pop(TrackerFactory.TRACKER)
+            # removing tracker to log config as hyperparameter
+        self.mlflow_tracker.log_params(params)
+        try:
+            self.train_loop(
+                train_dataloader=train_loader,
+                label_mappings=label_mappings,
+                val_dataloader=val_loader,
+                train_sampler=train_sampler,
+            )
+        except Exception as e:
+            self.mlflow_tracker.end_run(status=TrackerFactory.RUN_FAILED)
+            logger.exception("training failed, closing mlflow run")
+            raise e
+        finally:
+            self.mlflow_tracker.end_run()
+            self.writer.close()
+            self.kfp_writer.write_metric()
 
     def train_loop(
         self,
@@ -310,21 +330,23 @@ class FasterRCNN(Estimator):
                 )
 
                 self.writer.add_scalar(
-                    "training/intermediate_loss",
-                    intermediate_loss,
-                    examples_seen,
+                    _TRAIN_INTERMEDIATE_LOSS, intermediate_loss, examples_seen,
+                )
+                self.mlflow_tracker.log_metric(
+                    _TRAIN_INTERMEDIATE_LOSS, intermediate_loss
                 )
             losses_grad.backward()
             if (i + 1) % accumulation_steps == 0:
                 optimizer.step()
                 lr_scheduler.step()
                 optimizer.zero_grad()
-
-        self.writer.add_scalar("training/loss", loss_metric.compute(), epoch)
+        loss_metric_c = loss_metric.compute()
+        self.writer.add_scalar(_TRAIN_LOSS, loss_metric_c, epoch)
         self.writer.add_scalar(
             "training/lr", optimizer.param_groups[0]["lr"], epoch
         )
         loss_metric.reset()
+        self.mlflow_tracker.log_metric(_TRAIN_LOSS, loss_metric_c)
 
     def evaluate(self, test_data, **kwargs):
         """evaluate given dataset."""
@@ -344,14 +366,27 @@ class FasterRCNN(Estimator):
             config, test_dataset, test_sampler, TEST, self.distributed
         )
         self.model.to(self.device)
-        self.evaluate_per_epoch(
-            data_loader=test_loader,
-            epoch=0,
-            label_mappings=label_mappings,
-            synchronize_metrics=self.sync_metrics,
-        )
-        self.writer.close()
-        self.kfp_writer.write_metric()
+
+        params = self.config.clone()
+        if params.get(TrackerFactory.TRACKER):
+            params.pop(TrackerFactory.TRACKER)
+            # removing tracker to log config as hyperparameter
+        self.mlflow_tracker.log_params(params)
+        try:
+            self.evaluate_per_epoch(
+                data_loader=test_loader,
+                epoch=0,
+                label_mappings=label_mappings,
+                synchronize_metrics=self.sync_metrics,
+            )
+        except Exception as e:
+            self.mlflow_tracker.end_run(status=TrackerFactory.RUN_FAILED)
+            logger.exception("evaluate failed, closing mlflow run")
+            raise e
+        finally:
+            self.mlflow_tracker.end_run()
+            self.writer.close()
+            self.kfp_writer.write_metric()
 
     @torch.no_grad()
     def evaluate_per_epoch(
@@ -424,7 +459,8 @@ class FasterRCNN(Estimator):
         val_loss = loss_metric.compute()
         logger.info(f"validation loss is {val_loss}")
 
-        self.writer.add_scalar("val/loss", val_loss, epoch)
+        self.writer.add_scalar(_VAL_LOSS, val_loss, epoch)
+        self.mlflow_tracker.log_metric(_VAL_LOSS, val_loss)
 
         torch.set_num_threads(n_threads)
 
@@ -438,16 +474,18 @@ class FasterRCNN(Estimator):
         for metric_name, metric in self.metrics.items():
             result = metric.compute()
             logger.debug(result)
-            logger.info(f"metric {metric_name} has result: {result}")
             if metric.TYPE == "scalar":
+                logger.info(f"metric {metric_name} has result: {result}")
                 self.writer.add_scalar(f"val/{metric_name}", result, epoch)
                 self.kfp_writer.add_metric(name=metric_name, val=result)
+                self.mlflow_tracker.log_metric(f"val/{metric_name}", result)
             # TODO (YC) This is hotfix to allow user map between label_id
             # to label_name during model evaluation. In ideal cases this mapping
             # should be available before training/evaluation dataset was loaded.
             # label_id that was missing from label_name should be removed from
             # dataset and the training procedure.
             elif metric.TYPE == "metric_per_label":
+                logger.info(f"metric {metric_name} has result: {result}")
                 label_results = {
                     label_mappings.get(id, str(id)): value
                     for id, value in result.items()
@@ -458,6 +496,11 @@ class FasterRCNN(Estimator):
                 )
                 fig = metric_per_class_plot(metric_name, result, label_mappings)
                 self.writer.add_figure(f"{metric_name}-per-class", fig, epoch)
+            elif metric.TYPE == "precision_recall":
+                fig = pr_curve_plot(
+                    pr_results=result, label_mappings=label_mappings
+                )
+                self.writer.add_figure(f"{metric_name}", fig, epoch)
 
     def save(self, path):
         """Serialize Estimator to path.
@@ -1049,7 +1092,7 @@ def metric_per_class_plot(metric_name, data, label_mappings, figsize=(20, 10)):
         metric_name (str): metric name.
         data (dict): a dictionary of metric per label.
         label_mappings (dict): a dict of {label_id: label_name} mapping
-        figsize (tuple): figure size of the plot. Default is (20, 10)
+        figsize (tuple): figure size of the plot. Default is (15, 8)
 
     Returns (matplotlib.pyplot.figure):
         a bar plot for metric per class.
@@ -1070,6 +1113,31 @@ def metric_per_class_plot(metric_name, data, label_mappings, figsize=(20, 10)):
     return fig
 
 
+def pr_curve_plot(pr_results={}, label_mappings={}, figsize=(15, 8)):
+    """PR curve plot for each class.
+
+    Args:
+        pr_results (dict): a dict of {label_id: (precision, recall)} mapping
+        label_mappings (dict): a dict of {label_id: label_name} mapping
+        figsize (tuple): figure size of the plot. Default is (15, 8)
+
+    Returns (matplotlib.pyplot.figure):
+        a PR curve plot for each class.
+    """
+    fig = plt.figure(figsize=figsize)
+    plt.title("PR Curve")
+    plt.xlabel("Recall")
+    plt.ylabel("Precision")
+    plt.xlim(-0.01, 1.0)
+    plt.ylim(-0.01, 1.1)
+    for id in pr_results:
+        precision, recall = pr_results[id]
+        plt.plot(recall, precision, label=label_mappings[id])
+    plt.legend(loc="upper right")
+    plt.grid(True)
+    return fig
+
+
 class BoxListToTensor:
     """transform to bboxes to Tensor."""
 
